Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/edwh_uptime_plugin/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
src/edwh_uptime_plugin/uptime_plugin.py | 113 | 113 | 0 | 50 | 0 | 0%
src/edwh_uptime_plugin/uptimerobot.py | 124 | 20 | 0 | 14 | 2 | 81%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_api.py | 29 | 6 | 0 | 6 | 2 | 77%
Total | 266 | 139 | 0 | 70 | 4 | 41%

No items found using the specified filter.